==> haskell-aeson-casing-0.2.0.0-225.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-casing.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson-casing
version:              0.2.0.0
visibility:           public
id:                   aeson-casing-0.2.0.0-AslSveij60I8Gr7VRX3X2y
key:                  aeson-casing-0.2.0.0-AslSveij60I8Gr7VRX3X2y
license:              MIT
maintainer:           andrewrademacher@gmail.com
author:               Andrew Rademacher
synopsis:
    Tools to change the formatting of field names in Aeson
    instances.

description:
    Tools to change the formatting of field names in Aeson
    instances. This includes CamelCasing, Pascal Casing and
    Snake Casing.

category:             Data
abi:                  c9a1bb0cbd763232d40600c60957dc3e
exposed:              True
exposed-modules:      Data.Aeson.Casing Data.Aeson.Casing.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/aeson-casing-0.2.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/aeson-casing-0.2.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/aeson-casing-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-casing
hs-libraries:         HSaeson-casing-0.2.0.0-AslSveij60I8Gr7VRX3X2y
depends:              aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi base-4.18.2.1
haddock-interfaces:
    /usr/share/doc/haskell-aeson-casing/html/aeson-casing.haddock

haddock-html:         /usr/share/doc/haskell-aeson-casing/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-casing-0.2.0.0-226-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-casing.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson-casing
version:              0.2.0.0
visibility:           public
id:                   aeson-casing-0.2.0.0-CHKI9jgLm75DTsCBp5yLrQ
key:                  aeson-casing-0.2.0.0-CHKI9jgLm75DTsCBp5yLrQ
license:              MIT
maintainer:           andrewrademacher@gmail.com
author:               Andrew Rademacher
synopsis:
    Tools to change the formatting of field names in Aeson
    instances.

description:
    Tools to change the formatting of field names in Aeson
    instances. This includes CamelCasing, Pascal Casing and
    Snake Casing.

category:             Data
abi:                  c90aafcfb12f296579ba16562630f399
exposed:              True
exposed-modules:      Data.Aeson.Casing Data.Aeson.Casing.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/aeson-casing-0.2.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/aeson-casing-0.2.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/aeson-casing-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-casing
hs-libraries:         HSaeson-casing-0.2.0.0-CHKI9jgLm75DTsCBp5yLrQ
depends:              aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y base-4.18.2.1
haddock-interfaces:
    /usr/share/doc/haskell-aeson-casing/html/aeson-casing.haddock

haddock-html:         /usr/share/doc/haskell-aeson-casing/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
